@@ -28,8 +28,8 @@ def merge_vertices(mesh,
                    digits_uv=4,
                    **kwargs):
     """
-    Removes duplicate vertices. By default,  based on integer hashes of
-    each row.
+    Removes duplicate vertices, grouped by position and
+    optionally texture coordinate and normal.
 
     Parameters
     -------------
@@ -55,11 +55,11 @@ def merge_vertices(mesh,
     # if we have a ton of unreferenced vertices it will
     # make the unique_rows call super slow so cull first
     if hasattr(mesh, 'faces') and len(mesh.faces) > 0:
-        referenced = np.zeros(len(mesh.vertices), dtype=np.bool)
+        referenced = np.zeros(len(mesh.vertices), dtype=bool)
         referenced[mesh.faces] = True
     else:
         # this is used for geometry without faces
-        referenced = np.ones(len(mesh.vertices), dtype=np.bool)
+        referenced = np.ones(len(mesh.vertices), dtype=bool)
 
     # collect vertex attributes into sequence we can stack
     stacked = [mesh.vertices * (10 ** digits_vertex)]
@@ -224,11 +224,13 @@ def float_to_int(data, digits=None, dtype=np.int32):
     # if the data is empty we are also done
     if data.dtype.kind in 'ib' or data.size == 0:
         return data.astype(dtype)
+    elif data.dtype.kind != 'f':
+        data = data.astype(np.float64)
 
     # populate digits from kwargs
     if digits is None:
         digits = util.decimal_to_digits(tol.merge)
-    elif isinstance(digits, float) or isinstance(digits, np.float):
+    elif isinstance(digits, float) or isinstance(digits, np.float64):
         digits = util.decimal_to_digits(digits)
     elif not (isinstance(digits, int) or isinstance(digits, np.integer)):
         log.warning('Digits were passed as %s!', digits.__class__.__name__)
@@ -315,7 +317,7 @@ def unique_bincount(values,
 
     # which bins are occupied at all
     # counts are integers so this works
-    unique_bin = counts.astype(np.bool)
+    unique_bin = counts.astype(bool)
 
     # which values are unique
     # indexes correspond to original values
@@ -415,11 +417,11 @@ def unique_rows(data, digits=None):
       Index in data which is a unique row
     inverse : (n,) int
       Array to reconstruct original
-      Example: unique[inverse] == data
+      Example: data[unique][inverse] == data
     """
-    hashes = hashable_rows(data, digits=digits)
-    garbage, unique, inverse = np.unique(
-        hashes,
+    rows = hashable_rows(data, digits=digits)
+    _, unique, inverse = np.unique(
+        rows,
         return_index=True,
         return_inverse=True)
 
@@ -473,7 +475,7 @@ def unique_value_in_row(data, unique=None):
     if unique is None:
         unique = np.unique(data)
     data = np.asanyarray(data)
-    result = np.zeros_like(data, dtype=np.bool, subok=False)
+    result = np.zeros_like(data, dtype=bool, subok=False)
     for value in unique:
         test = np.equal(data, value)
         test_ok = test.sum(axis=1) == 1
@@ -648,7 +650,7 @@ def group_distance(values, distance):
                            dtype=np.float64)
 
     consumed = np.zeros(len(values),
-                        dtype=np.bool)
+                        dtype=bool)
     tree = cKDTree(values)
 
     # (n, d) set of values that are unique
@@ -660,7 +662,7 @@ def group_distance(values, distance):
         if consumed[index]:
             continue
         group = np.array(tree.query_ball_point(value, distance),
-                         dtype=np.int)
+                         dtype=np.int64)
         consumed[group] = True
         unique.append(np.median(values[group], axis=0))
         groups.append(group)
@@ -729,9 +731,8 @@ def blocks(data,
 
     # find the inflection points
     # AKA locations where the array goes from True to False.
-    infl = np.concatenate(([0],
-                           np.nonzero(np.diff(data))[0] + 1,
-                           [len(data)]))
+    infl = np.concatenate((
+        [0], np.nonzero(np.diff(data))[0] + 1, [len(data)]))
     infl_len = np.diff(infl)
     # check the length of each group
     infl_ok = np.logical_and(infl_len >= min_len,
